# Table of Contents

- [tagging](<./tagging.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Tagging](<./Tagging.md>)
  - [Introduction](<./Tagging/Introduction.md>)
  - [Creating a Tag Group](<./Tagging/Creating-a-Tag-Group.md>)
  - [Creating and Editing Tags in a Tag Group](<./Tagging/Creating-and-Editing-Tags-in-a-Tag-Group.md>)
  - [Editing a Tag Group](<./Tagging/Editing-a-Tag-Group.md>)
  - [Deleting Tags and Tag Groups](<./Tagging/Deleting-Tags-and-Tag-Groups.md>)
